@@ -16,13 +16,13 @@ use rand::{thread_rng, Rng};
 use std::{
     fs::File,
     io::{BufWriter, Cursor, Error as IoError, ErrorKind, Read, Write},
-    path::{Path, PathBuf},
+    path::Path,
 };
 
 use byteorder::{BigEndian, ReadBytesExt, WriteBytesExt};
 
-use aes_ctr::{
-    cipher::{NewStreamCipher, SyncStreamCipher},
+use aes::{
+    cipher::{NewCipher, StreamCipher},
     Aes256Ctr,
 };
 use hkdf::Hkdf;
@@ -152,7 +152,6 @@ pub(crate) const PBKDF_COUNT: u32 = 10_000;
 /// [hkdf]: https://en.wikipedia.org/wiki/HKDF
 /// [hmac]: https://en.wikipedia.org/wiki/HMAC
 pub struct EncryptedMmapDirectory {
-    path: PathBuf,
     mmap_dir: tantivy::directory::MmapDirectory,
     encryption_key: KeyBuffer,
     mac_key: KeyBuffer,
@@ -167,7 +166,6 @@ impl EncryptedMmapDirectory {
         let mmap_dir = tantivy::directory::MmapDirectory::open(&path)?;
 
         Ok(EncryptedMmapDirectory {
-            path: PathBuf::from(&path),
             mmap_dir,
             encryption_key,
             mac_key,
@@ -305,7 +303,7 @@ impl EncryptedMmapDirectory {
     fn expand_store_key(store_key: &[u8]) -> std::io::Result<KeyDerivationResult> {
         let mut hkdf_result = Zeroizing::new([0u8; KEY_SIZE * 2]);
 
-        let hkdf = Hkdf::<Sha512>::new(None, &store_key);
+        let hkdf = Hkdf::<Sha512>::new(None, store_key);
         hkdf.expand(&[], &mut *hkdf_result).map_err(|e| {
             IoError::new(
                 ErrorKind::Other,
@@ -366,10 +364,10 @@ impl EncryptedMmapDirectory {
             return Err(IoError::new(ErrorKind::Other, "invalid MAC of the store key").into());
         }
 
-        let mut decryptor = Aes256Ctr::new_var(&key, &iv).map_err(|e| {
+        let mut decryptor = Aes256Ctr::new_from_slices(&key, &iv).map_err(|e| {
             IoError::new(
                 ErrorKind::Other,
-                format!("error creating decryptor: {:?}", e),
+                format!("error initializing cipher {:?}", e),
             )
         })?;
 
@@ -392,12 +390,12 @@ impl EncryptedMmapDirectory {
         encrypted_data: &[u8],
         hmac_key: &[u8],
     ) -> std::io::Result<Hmac<Sha256>> {
-        let mut hmac = Hmac::<Sha256>::new_varkey(hmac_key)
+        let mut hmac = Hmac::<Sha256>::new_from_slice(hmac_key)
             .map_err(|e| IoError::new(ErrorKind::Other, format!("error creating hmac: {:?}", e)))?;
         hmac.update(&[version]);
-        hmac.update(&iv);
-        hmac.update(&salt);
-        hmac.update(&encrypted_data);
+        hmac.update(iv);
+        hmac.update(salt);
+        hmac.update(encrypted_data);
         Ok(hmac)
     }
 
@@ -440,15 +438,15 @@ impl EncryptedMmapDirectory {
     ) -> Result<(), OpenDirectoryError> {
         // Generate a random initialization vector for our AES encryptor.
         let iv = EncryptedMmapDirectory::generate_iv()?;
-        let mut encryptor = Aes256Ctr::new_var(&key, &iv).map_err(|e| {
+        let mut encryptor = Aes256Ctr::new_from_slices(key, &iv).map_err(|e| {
             IoError::new(
                 ErrorKind::Other,
-                format!("error creating encryptor: {:?}", e),
+                format!("error initializing cipher: {:?}", e),
             )
         })?;
 
         let mut encrypted_key = [0u8; KEY_SIZE];
-        encrypted_key.copy_from_slice(&store_key);
+        encrypted_key.copy_from_slice(store_key);
 
         let mut key_file = File::create(key_path)?;
 
@@ -456,7 +454,7 @@ impl EncryptedMmapDirectory {
         // decrypt the key again.
         key_file.write_all(&[VERSION])?;
         key_file.write_all(&iv)?;
-        key_file.write_all(&salt)?;
+        key_file.write_all(salt)?;
         key_file.write_u32::<BigEndian>(pbkdf_count)?;
 
         // Encrypt our key.
@@ -472,7 +470,7 @@ impl EncryptedMmapDirectory {
         // Calculate a MAC for our encrypted key and store it in the file before
         // the key.
         let mac =
-            EncryptedMmapDirectory::calculate_hmac(VERSION, &iv, &salt, &encrypted_key, &hmac_key)?;
+            EncryptedMmapDirectory::calculate_hmac(VERSION, &iv, salt, &encrypted_key, hmac_key)?;
         let mac = mac.finalize();
         let mac = mac.into_bytes();
         key_file.write_all(mac.as_slice())?;
@@ -484,8 +482,8 @@ impl EncryptedMmapDirectory {
     }
 
     /// Generate a random IV.
-    fn generate_iv() -> Result<Vec<u8>, OpenDirectoryError> {
-        let mut iv = vec![0u8; IV_SIZE];
+    fn generate_iv() -> Result<[u8; IV_SIZE], OpenDirectoryError> {
+        let mut iv = [0u8; IV_SIZE];
         let mut rng = thread_rng();
         rng.try_fill(&mut iv[..])
             .map_err(|e| IoError::new(ErrorKind::Other, format!("error generating iv: {:?}", e)))?;
@@ -506,12 +504,7 @@ impl EncryptedMmapDirectory {
     fn rederive_key(passphrase: &str, salt: &[u8], pbkdf_count: u32) -> KeyDerivationResult {
         let mut pbkdf_result = Zeroizing::new([0u8; KEY_SIZE * 2]);
 
-        pbkdf2::<Hmac<Sha512>>(
-            &passphrase.as_bytes(),
-            &salt,
-            pbkdf_count,
-            &mut *pbkdf_result,
-        );
+        pbkdf2::<Hmac<Sha512>>(passphrase.as_bytes(), salt, pbkdf_count, &mut *pbkdf_result);
         let (key, hmac_key) = pbkdf_result.split_at(KEY_SIZE);
         (
             Zeroizing::new(Vec::from(key)),
@@ -634,7 +627,7 @@ impl Directory for EncryptedMmapDirectory {
 
 // This Tantivy trait is used to indicate when no more writes are expected to be
 // done on a writer.
-impl<E: NewStreamCipher + SyncStreamCipher, M: Mac + NewMac, W: Write> TerminatingWrite
+impl<E: NewCipher + StreamCipher, M: Mac + NewMac, W: Write> TerminatingWrite
     for AesWriter<E, M, W>
 {
     fn terminate_ref(&mut self, _: AntiCallToken) -> std::io::Result<()> {
