@@ -171,7 +171,7 @@ impl Writer {
 
     /// Delete the event with the given event id from the index.
     pub fn delete_event(&mut self, event_id: &str) {
-        let term = Term::from_field_text(self.event_id_field, &event_id);
+        let term = Term::from_field_text(self.event_id_field, event_id);
         self.inner.delete_term(term);
         self.inner.commit().unwrap();
     }
@@ -206,7 +206,7 @@ impl IndexSearcher {
 
         let term = if let Some(room) = &config.room_id {
             keys.push(self.room_id_field);
-            format!("+room_id:\"{}\" AND \"{}\"", room, term)
+            format!("+room_id:\"{}\" AND {}", room, term)
         } else if term.is_empty() {
             "*".to_owned()
         } else {
@@ -307,7 +307,7 @@ impl IndexSearcher {
                     og_limit,
                     limit + SEARCH_LIMIT_INCREMENT,
                     order_by_recency,
-                    &previous_results,
+                    previous_results,
                     query,
                 )
             }
@@ -323,7 +323,7 @@ impl IndexSearcher {
     ) -> Result<SearchResult, tv::TantivyError> {
         let past_search = if let Some(token) = &config.next_batch {
             let mut search_cache = self.search_cache.write().unwrap();
-            search_cache.get_mut(&token).cloned()
+            search_cache.get_mut(token).cloned()
         } else {
             None
         };
@@ -451,7 +451,7 @@ impl Index {
     ) -> tv::Result<tv::Index> {
         match &config.passphrase {
             Some(p) => {
-                let dir = EncryptedMmapDirectory::open_or_create(path, &p, PBKDF_COUNT)?;
+                let dir = EncryptedMmapDirectory::open_or_create(path, p, PBKDF_COUNT)?;
                 tv::Index::open_or_create(dir, schema)
             }
             None => {
@@ -579,7 +579,7 @@ fn add_events_to_differing_rooms() {
 
     let searcher = index.get_searcher();
     let result = searcher
-        .search("Test", &SearchConfig::new().for_room(&EVENT.room_id))
+        .search("Test", SearchConfig::new().for_room(&EVENT.room_id))
         .unwrap()
         .results;
 
